//////////////////////////////////////////////////////////////////////////////
// * File name: csl_i2c_power_monitor.c
// *                                                                          
// * Description: This file includes main() and system initialization funcitons.
// *                                                                          
// * Copyright (C) 2010 Texas Instruments Incorporated - http://www.ti.com/ 
// *                                                                          
// *                                                                          
// *  Redistribution and use in source and binary forms, with or without      
// *  modification, are permitted provided that the following conditions      
// *  are met:                                                                
// *                                                                          
// *    Redistributions of source code must retain the above copyright        
// *    notice, this list of conditions and the following disclaimer.         
// *                                                                          
// *    Redistributions in binary form must reproduce the above copyright     
// *    notice, this list of conditions and the following disclaimer in the   
// *    documentation and/or other materials provided with the                
// *    distribution.                                                         
// *                                                                          
// *    Neither the name of Texas Instruments Incorporated nor the names of   
// *    its contributors may be used to endorse or promote products derived   
// *    from this software without specific prior written permission.         
// *                                                                          
// *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS     
// *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT       
// *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR   
// *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT    
// *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,   
// *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT        
// *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,   
// *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY   
// *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT     
// *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE   
// *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.    
// *                                                                          
//////////////////////////////////////////////////////////////////////////////

#include "csl_pll.h"
#include "csl_pllAux.h"
#include "lcdc_panel.h"
#include "ti_logo_32x32.h"
#include "rtc.h"
#include "register_system.h"
#include <csl_i2c.h>
#include <stdio.h>
#include <csl_general.h>
#include <csl_rtc.h>
#include <csl_intc.h>

#define CSL_I2C_TEST_PASSED      (0)
#define CSL_I2C_TEST_FAILED      (1)

#define CSL_I2C_DATA_SIZE        (64)
#define CSL_EEPROM_ADDR_SIZE     (2)
#define CSL_I2C_OWN_ADDR         (0x2F)

#define CSL_I2C_SYS_CLK          	(100)
#define CSL_I2C_BUS_FREQ         	(10)
#define CSL_I2C_EEPROM_ADDR		 	(0x50)

// Power monitoring by AN219
#define CSL_I2C_CODEC_ADDR		 	(0x18)
#define CSL_I2C_POWER_CORE_ADDR  	(0x40)
#define CSL_I2C_POWER_IO2_ADDR   	(0x42)
#define CSL_I2C_POWER_USB1p3_ADDR  	(0x43)
#define CSL_I2C_POWER_IO1_ADDR  	(0x44)
#define CSL_I2C_POWER_EVM3p3_ADDR  	(0x45)
#define CSL_I2C_POWER_EVM1p8_ADDR  	(0x46)
#define CSL_I2C_POWER_EVMVIN_ADDR  	(0x47)

#define RTC_CLK						(0.032768)  // MHZ

//#define EXT_CLK						(12.000)	// MHz

PLL_Obj pllObj;
PLL_Handle hPll;
PLL_Config pllCfg;
PLL_Config *pConfigInfo;

#ifdef EXT_CLK
PLL_Config pllCfg_120MHz    = {0x8E48, 0x616E, 0x0806, 0x0001};
PLL_Config pllCfg_150MHz    = {0x8F7B, 0x613D, 0x0806, 0x0001};
PLL_Config pllCfg_160MHz    = {0x8FFB, 0x6133, 0x0806, 0x0001};
PLL_Config pllCfg_170MHz    = {0x8FFB, 0x6120, 0x0806, 0x0001};
PLL_Config pllCfg_180MHz    = {0x8FFB, 0x6110, 0x0806, 0x0001};
PLL_Config pllCfg_190MHz    = {0x8FFB, 0x6101, 0x0806, 0x0001};
#else
PLL_Config pllCfg_12p288MHz = {0x8173, 0x8000, 0x0806, 0x0000};
PLL_Config pllCfg_40MHz     = {0x898C, 0x8000, 0x0806, 0x0201};
PLL_Config pllCfg_60MHz     = {0x8728, 0x8000, 0x0806, 0x0000};
PLL_Config pllCfg_75MHz     = {0x88F1, 0x8000, 0x0806, 0x0000};
PLL_Config pllCfg_100MHz    = {0x8BEC, 0x8000, 0x0806, 0x0000};
PLL_Config pllCfg_120MHz    = {0x8E4F, 0x8000, 0x0806, 0x0000};
#endif

Uint16  gI2cWrBuf[CSL_I2C_DATA_SIZE + CSL_EEPROM_ADDR_SIZE];
Uint16  gI2cRdBuf[CSL_I2C_DATA_SIZE];

Uint16  gPowerReg[12];


CSL_I2cSetup     i2cSetup;
CSL_I2cConfig    i2cConfig;

CSL_LcdcHandle   hLcdc;
char Freq[7], Core[7], IO1[7], POWER[7];

extern Uint16 banner_sel, draw_banner, freq_sel, chan_freq;

/**
 *  \brief  Tests I2C Power monitor operation
 *
 *  \param  none
 *
 *  \return Test result
 */
CSL_Status CSL_i2cPowerTest(void);

/**
 *  \brief  main function
 *
 *  \param  none
 *
 *  \return none
 */

void c5515_init();

void main(void)
{
	CSL_Status    result;
	
	c5515_init();

	result = PLL_init(&pllObj, CSL_PLL_INST_0);
    if(CSL_SOK != result)
    {
       printf("PLL init failed \n");
    }	
	
	hPll = (PLL_Handle)(&pllObj);
	result = PLL_reset(hPll);
    if(CSL_SOK != result)
    {
       printf("PLL reset failed \n");
    }
#ifdef EXT_CLK
	 /* Configure the PLL for 120MHz */
    pConfigInfo = &pllCfg_120MHz;
#else
	 /* Configure the PLL for 60MHz */
    pConfigInfo = &pllCfg_60MHz;
#endif
	result = PLL_config (hPll, pConfigInfo);
    if(CSL_SOK != result)
    {
       printf("PLL config failed\n");
       
    }

	rtc();	// set RTC
	
	result =  CSL_i2cPowerTest();
}

/**
 *  \brief  Tests I2C Power test
 *
 *  \param  none
 *
 *  \return Test result
 */
CSL_Status  CSL_i2cPowerTest(void)
{
	CSL_Status         status;
	CSL_Status         result;
	Uint16             startStop, i, j, k;
	volatile Uint16    looper;
	CSL_LcdcObj 		lcdcObj;
	CSL_LcdcHwSetup     lcdcLiddSetup;
	CSL_LcdcConfigLidd  configLIDD;
	CSL_LcdcLiddTiming  timingCs0LIDD;
	float				core_i, core_power, core_v, freq;
	Uint16				PLL_FB, PLL_RD, PLL_OD;
	Uint16				freq_sel=0, toggle_freq=1;
	Uint32		romcolor[8]={0x003F3F3F, 
							 0x0000003F, 
							 0x00003F00,
							 0x00003F3F,
							 0x003F0000,
							 0x003F003F,
							 0x003F3F00,
							 0x003F3F3F};


	result = CSL_I2C_TEST_FAILED;

    configLIDD.clkDiv      = 0x0;      
    configLIDD.fdoneIntEn  = CSL_LCDC_LIDD_FDONE_DISABLE;
    configLIDD.dmaCs0Cs1   = CSL_LCDC_LIDD_CS0;
    configLIDD.dmaEnable   = CSL_LCDC_LIDD_DMA_DISABLE;
    configLIDD.polControl  = 0x0000;
    configLIDD.modeSel     = CSL_LCDC_LIDD_ASYNC_MPU80;

    timingCs0LIDD.wSu      = 0x1F;
    timingCs0LIDD.wStrobe  = 0x3F;
    timingCs0LIDD.wHold    = 0x0F;
    timingCs0LIDD.rSu      = 0x1F;
    timingCs0LIDD.rStrobe  = 0x3F;
    timingCs0LIDD.rHold    = 0x0F;
    timingCs0LIDD.ta       = 0x01;

     /* Set up of LCDC LIDD control Register */
    lcdcLiddSetup.config    = configLIDD;
    /* Select DMA not to write to CS1 */
    lcdcLiddSetup.useCs1    = CSL_LCDC_LIDD_NOT_USE_CS1;
    /* LIDD timing control setting  */
    lcdcLiddSetup.timingCs0 = timingCs0LIDD;
    /* Currently no Extended setup is used. So initialize to NULL */
    lcdcLiddSetup.extendSetup         = NULL;

	/* Initialize I2C module */
	status = LCD_init();
	if(status != CSL_SOK)
	{
		printf("I2C Init Failed!!\n");
		return(result);
	}
	/* Configure GPIO for LCD */
	CSL_FINST(CSL_SYSCTRL_REGS->EBSR, SYS_EBSR_PPMODE, MODE2);
	CSL_FINST(CSL_SYSCTRL_REGS->EBSR, SYS_EBSR_SP1MODE, MODE2);
    CSL_GPIO_REGS->IODIR1     = CSL_LCD_GPIO_MASK;
    CSL_GPIO_REGS->IOOUTDATA1 = CSL_LCD_GPIO_MASK;

	hLcdc = LCD_open(0, &lcdcObj, &status);
	if (hLcdc == NULL)
	{
		printf("LCD_open Failed\n");
		return(CSL_ESYS_FAIL);
	}

    /* LCD handled by for LIDD Controller */
	status = LCD_setup(hLcdc, &lcdcLiddSetup);
	if (status != CSL_SOK)
	{
		return(status);
	}

	/* Setup for the LCDC Panel */
	panelSetup(CSL_LCDC_LIDD_CS0);

	for (k=0; k<8; k++) {
		draw_ROM_table ( 0,  0, romcolor[k], 0);
		for (i=0; i<10000; i++) {
			for (j=0; j<2000; j++) {}
		}	
	}
	
	lcdClearPanel(0);	
	status = draw_ti_logo(CSL_LCDC_LIDD_CS0);
	draw_string(40,16,"TEXAS",0x0000003F,CSL_LCDC_LIDD_CS0); 			// RED
	draw_string(40,32,"INSTRUMENTS",0x0000003F,CSL_LCDC_LIDD_CS0); 		// RED
	draw_string(8,64, "Freq:       MHz",0x003F0000,CSL_LCDC_LIDD_CS0); 	// BLUE
	draw_string(8,88, "Core:       mA",0x00003F00,CSL_LCDC_LIDD_CS0); 	// GREEN
    draw_string(8,112,"Pwr:     mW/MHz",0x00003F00,CSL_LCDC_LIDD_CS0);	// GREEN

	/* Initialize I2C module */
	status = I2C_init(CSL_I2C0);
	if(status != CSL_SOK)
	{
		printf("I2C Init Failed!!\n");
		return(result);
	}

	/* Setup I2C module */
	i2cSetup.addrMode    = CSL_I2C_ADDR_7BIT;
	i2cSetup.bitCount    = CSL_I2C_BC_8BITS;
	i2cSetup.loopBack    = CSL_I2C_LOOPBACK_DISABLE;
	i2cSetup.freeMode    = CSL_I2C_FREEMODE_DISABLE;
	i2cSetup.repeatMode  = CSL_I2C_REPEATMODE_DISABLE;
	i2cSetup.ownAddr     = CSL_I2C_OWN_ADDR;
	i2cSetup.sysInputClk = CSL_I2C_SYS_CLK;
	i2cSetup.i2cBusFreq  = CSL_I2C_BUS_FREQ;
	startStop            = ((CSL_I2C_START) | (CSL_I2C_STOP));

	status = I2C_setup(&i2cSetup);
	if(status != CSL_SOK)
	{
		printf("I2C Setup Failed!!\n");
		return(result);
	}

	i=1;
    gI2cWrBuf[0]= i;
	status = I2C_write(gI2cWrBuf, 1, CSL_I2C_POWER_CORE_ADDR,
	                   TRUE, startStop, CSL_I2C_MAX_TIMEOUT);
	if(status != CSL_SOK)
	{
		printf("I2C Write Failed!!\n");
		return(result);
	}

	/* Give some delay */
	for(looper = 0; looper < CSL_I2C_MAX_TIMEOUT; looper++){asm("	nop");}

	/*  IO1  */
	status = I2C_write(gI2cWrBuf, 1, CSL_I2C_POWER_IO1_ADDR,
	                  TRUE, startStop, CSL_I2C_MAX_TIMEOUT);
	if(status != CSL_SOK)
	{
		printf("I2C Write Failed!!\n");
		return(result);
	}

	/* Give some delay */
	for(looper = 0; looper < CSL_I2C_MAX_TIMEOUT; looper++){asm("	nop");}
					
    while(1) {
	  
	  if ((banner_sel==0) & (draw_banner ==1)) {
	  	  	draw_banner=0;
			drawRectangle(0,0,128,60,0x00000000,CSL_LCDC_LIDD_CS0 ); // clear banner area
			status = draw_ti_logo(CSL_LCDC_LIDD_CS0);
			draw_string(40,16,"TEXAS",0x0000003F,CSL_LCDC_LIDD_CS0); // RED
			draw_string(40,32,"INSTRUMENTS",0x0000003F,CSL_LCDC_LIDD_CS0); // RED
			asm("	bit(ST1,#13) = #0");	// XF LED off
	  }
	  else if ((banner_sel==2) & (draw_banner ==1)) {
	  	  	draw_banner=0;
			drawRectangle(0,0,128,60,0x00000000,CSL_LCDC_LIDD_CS0 ); // clear banner area			
			draw_string(8,16,"Industry Lowest",0x00003F3F,CSL_LCDC_LIDD_CS0); // YELLOW
			draw_string(8,32,"Power DSP C5515",0x003F003F,CSL_LCDC_LIDD_CS0); // PURPLE
	  }
	  else if ((banner_sel==3) & (chan_freq ==1) & toggle_freq) {
		chan_freq = 0;
		if (freq_sel > 5) freq_sel=0;

#ifdef EXT_CLK
		if (freq_sel == 0)
			pConfigInfo = &pllCfg_120MHz;
		else if (freq_sel == 1)
			pConfigInfo = &pllCfg_150MHz;
		else if (freq_sel == 2)
			pConfigInfo = &pllCfg_160MHz;
		else if (freq_sel == 3)
			pConfigInfo = &pllCfg_170MHz;
		else if (freq_sel == 4)
			pConfigInfo = &pllCfg_180MHz;
		else 
			pConfigInfo = &pllCfg_190MHz;

#else		
		if (freq_sel == 0)
			pConfigInfo = &pllCfg_12p288MHz;
		else if (freq_sel == 1)
			pConfigInfo = &pllCfg_40MHz;
		else if (freq_sel == 2)
			pConfigInfo = &pllCfg_60MHz;
		else if (freq_sel == 3)
			pConfigInfo = &pllCfg_75MHz;
		else if (freq_sel == 4)
			pConfigInfo = &pllCfg_100MHz;
		else 
			pConfigInfo = &pllCfg_120MHz;
#endif



		PLL_reset(hPll);
		result = PLL_config (hPll, pConfigInfo);
		freq_sel++;
		asm("	bit(ST1,#13) = #1");	// XF LED on
	  }	

	  status = PLL_getConfig(hPll, &pllCfg);
      if(status != CSL_SOK)
	  {
	    printf("TEST FAILED: PLL get config... Failed.\n");
		printf ("Reason: PLL_getConfig failed. [status = 0x%x].\n", status);
		return(result);
	  }

	  PLL_FB = pllCfg.PLLCNTL1 & 0x0FFF;
	  PLL_RD = pllCfg.PLLINCNTL & 0x0FFF;
#ifdef EXT_CLK
	  freq = (EXT_CLK / (PLL_RD+1)) * (PLL_FB+4);
	  
#else
	  freq = PLL_FB * RTC_CLK;
	  if (pllCfg.PLLOUTCNTL & 0x200) {
		PLL_OD = pllCfg.PLLOUTCNTL & 0xFF;
		freq = freq / (PLL_OD+1);
	  }
#endif
	  sprintf(Freq, "%3.1f",freq);
	  draw_string(56,64,Freq,0x003F3F00,CSL_LCDC_LIDD_CS0); // CYAN

	  /* Reading current and voltage */
	  for (i=1; i<3; i++) {

		/*  set subaddress  */
    	gI2cWrBuf[0]= i;
		status = I2C_write(gI2cWrBuf, 1, CSL_I2C_POWER_CORE_ADDR,
	                   TRUE, startStop, CSL_I2C_MAX_TIMEOUT);
		if(status != CSL_SOK)
		{
			printf("I2C Write Failed!!\n");
			return(result);
		}
		/* Give some delay */
		for(looper = 0; looper < CSL_I2C_MAX_TIMEOUT; looper++){asm("	nop");}

		/* Read data */
		status = I2C_read(&gPowerReg[i*2], 2, CSL_I2C_POWER_CORE_ADDR,
	                   TRUE, startStop, CSL_I2C_MAX_TIMEOUT, FALSE);
		if(status != CSL_SOK)
		{
			printf("I2C Read Failed!!\n");
			return(result);
		}

		/* Give some delay */
		for(looper = 0; looper < CSL_I2C_MAX_TIMEOUT; looper++){asm("	nop");}
	 }

	 core_i= ((gPowerReg[2]  << 8) + gPowerReg[3])* 0.01001;
	 sprintf(Core, "       ");
	 sprintf(Core, "%2.2f", core_i);
	 draw_string(56,88,Core,0x00003F3F,CSL_LCDC_LIDD_CS0); // YELLOW

	 core_v= ((gPowerReg[4]  << 5) + gPowerReg[5]>>3) * 0.02;
	 core_power = (core_v * core_i)/freq ; // power/MHz;
	 sprintf(POWER, "%1.2f", core_power);
	 draw_string(44,112,POWER,0x003F3F3F,CSL_LCDC_LIDD_CS0); // WHITE
    }

}



