//////////////////////////////////////////////////////////////////////////////
// * File name: csl_general.h
// *                                                                          
// * Description: CSL general header file
// *                                                                          
// * Copyright (C) 2010 Texas Instruments Incorporated - http://www.ti.com/ 
// *                                                                          
// *                                                                          
// *  Redistribution and use in source and binary forms, with or without      
// *  modification, are permitted provided that the following conditions      
// *  are met:                                                                
// *                                                                          
// *    Redistributions of source code must retain the above copyright        
// *    notice, this list of conditions and the following disclaimer.         
// *                                                                          
// *    Redistributions in binary form must reproduce the above copyright     
// *    notice, this list of conditions and the following disclaimer in the   
// *    documentation and/or other materials provided with the                
// *    distribution.                                                         
// *                                                                          
// *    Neither the name of Texas Instruments Incorporated nor the names of   
// *    its contributors may be used to endorse or promote products derived   
// *    from this software without specific prior written permission.         
// *                                                                          
// *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS     
// *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT       
// *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR   
// *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT    
// *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,   
// *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT        
// *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,   
// *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY   
// *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT     
// *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE   
// *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.    
// *                                                                          
//////////////////////////////////////////////////////////////////////////////

/** @file csl_general.h
 *
 *  @brief CSL general header file
 *
 *  This file contains the general CSL macros or definitions that are required
 *  to enable few functionalities specific to the chip revision. This file is
 *  included in all the cslr files. All the CSL applications should include
 *  this file.
 *
 *  Path: \(CSLPATH)\ inc
 */

/* ============================================================================
 * Revision History
 * ================
 * 07-Jan-2009 Created
 * 28-Apr-2010 Added new macro definitions
 * 30-June-2010 Added new macro definitions for platforms
 * ============================================================================
 */

#ifndef _CSL_GENERAL_H_
#define _CSL_GENERAL_H_

#ifdef __cplusplus
extern "C" {
#endif

/*
 ******************************************************
 * CAUTION: DEFINE EITHER THE MACROS IN PART1 OR PART2.
 * DO NOT DEFINE MACROS IN BOTH PARTS.
 ******************************************************
 */

/** ***************************************************************************
 * --------------------------------------------------
 * PART1: CHIP VERSION MACRO DEFINITION FOR PG1.4 CSL
 * --------------------------------------------------
 *
 * Below macros are used to enable the source code specific to chip versions
 * TMS320VC5505 and TMS320VC5504. Design revision(DesignRev) of the DIE ID
 * regsiter(0x1C43 & 0x1C44) will have the value '4' for this chip set.
 *
 * 'CHIP_VC5505' indicates TMS320VC5505 DSP.
 * 'CHIP_VC5504' indicates TMS320VC5504 DSP.
 *
 * DSPs TMS320VC5505 and TMS320VC5504 are having the same peripherals but
 * they differ in the internal memory available.
 *
 * Defining any of the below macros will enable the code for both the DSPs
 * TMS320VC5504 and TMS320VC5505. Current CSL software does not have the code
 * that is specific to TMS320VC5504 DSP.
 */

/* TMS320VC5505 */
//#define CHIP_VC5505

/*
 * Below macro was the used to indicate TMS320VC5505 in old
 * CSL version. Here it is provided for backward compatibility
 */
//#define CHIP_5505


/* TMS320VC5504 */
//#define CHIP_VC5504

/*
 * Below macro was the used to indicate TMS320VC5504 in old
 * CSL version. Here it is provided for backward compatibility
 */
//#define CHIP_5504

/******************************* END OF PART1 *******************************/


/* Mapping of the old macros to the new macros */
#ifdef CHIP_5505
#define CHIP_VC5505
#endif

#ifdef CHIP_5504
#define CHIP_VC5504
#endif



/** ***************************************************************************
 * --------------------------------------------------
 * PART2: CHIP VERSION MACRO DEFINITION FOR PG2.0 CSL
 * --------------------------------------------------
 *
 * Below macros are used to enable the source code specific to chip versions
 * TMS320C5505, TMS320C5515, TMS320C5504, and TMS320C5514.
 * Design revision(DesignRev) of the DIE ID regsiter(0x1C43 & 0x1C44) will have
 * the value '5' for this chip set.
 *
 * 'CHIP_C5505_C5515' indicates TMS320C5505 and TMS320C5515.
 * 'CHIP_C5504_C5514' indicates TMS320C5504 and TMS320C5514.
 *
 * DSPs TMS320C5505 and TMS320C5515 are similar but certain LDOs not bonded out
 * for TMS320C5505 DSP.
 * DSPs TMS320C5504 and TMS320C5514 are similar but certain LDOs not bonded out
 * for TMS320C5504 DSP.
 *
 * DSPs TMS320C55x5 and TMS320C55x4 are having the same peripherals but
 * they differ in the internal memory available. 'x' stands for 0 or 1.
 *
 * Defining any of the below macros will enable the code for all the DSPs
 * TMS320C5504, TMS320C5505, TMS320C5514 and TMS320C5515.
 * Current CSL software does not have the code that is specific to TMS320C5504
 * and TMS320C5514 DSPs.
 */

#if (!(defined(CHIP_VC5505) || defined(CHIP_VC5504)))

/* TMS320C5505 and TMS320C5515 */
#define CHIP_C5505_C5515

/*
 * Below macro was the used to indicate TMS320C5505 and TMS320C5515 in old
 * CSL version. Here it is provided for backward compatibility
 */
//#define CHIP_5515


/* TMS320C5504 and TMS320C5514 */
#define CHIP_C5504_C5514

/*
 * Below macro was the used to indicate TMS320C5504 and TMS320C5514 in old
 * CSL version. Here it is provided for backward compatibility
 */
//#define CHIP_5514

#endif

/******************************* END OF PART2 *******************************/

/** ***************************************************************************
 * --------------------------------------------------
 * PART3: EVM VERSION MACRO DEFINITION FOR PG2.0 CSL
 * --------------------------------------------------
 *
 * Below macros are used to enable the source code specific to EVM versions
 */

#if (!(defined(CHIP_VC5505) || defined(CHIP_VC5504)))

//#define C5515_EVM

#if (!(defined(C5515_EVM)))
#define C5515_EZDSP
#endif

#else

#define VC5505_EVM

#if (!(defined(VC5505_EVM)))
#define VC5505_EZDSP
#endif

#endif
/******************************* END OF PART3 *******************************/


/* Mapping of the old macros to the new macros */
#ifdef CHIP_5515
#define CHIP_C5505_C5515
#endif

#ifdef CHIP_5514
#define CHIP_C5504_C5514
#endif


#ifdef __cplusplus
}
#endif

#endif    // _CSL_GENERAL_H_

