//////////////////////////////////////////////////////////////////////////////
// * File name: lcdc_panel.c
// *                                                                          
// * Description: This file includes main() and system initialization funcitons.
// *                                                                          
// * Copyright (C) 2010 Texas Instruments Incorporated - http://www.ti.com/ 
// *                                                                          
// *                                                                          
// *  Redistribution and use in source and binary forms, with or without      
// *  modification, are permitted provided that the following conditions      
// *  are met:                                                                
// *                                                                          
// *    Redistributions of source code must retain the above copyright        
// *    notice, this list of conditions and the following disclaimer.         
// *                                                                          
// *    Redistributions in binary form must reproduce the above copyright     
// *    notice, this list of conditions and the following disclaimer in the   
// *    documentation and/or other materials provided with the                
// *    distribution.                                                         
// *                                                                          
// *    Neither the name of Texas Instruments Incorporated nor the names of   
// *    its contributors may be used to endorse or promote products derived   
// *    from this software without specific prior written permission.         
// *                                                                          
// *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS     
// *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT       
// *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR   
// *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT    
// *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,   
// *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT        
// *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,   
// *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY   
// *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT     
// *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE   
// *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.    
// *                                                                          
//////////////////////////////////////////////////////////////////////////////
#include "lcdc_panel.h"

extern CSL_LcdcHandle hLcdc;

#pragma DATA_SECTION(CharGen_6x8, ".charrom")
Uint16 CharGen_6x8[256*3];

/**
 *  \brief  writing command of LIDD controller.
 *
 *  \param  cmd       [IN]  cmd value .
 *  \param  cs_flag   [IN]  chip select 0 or 1.
 *  \return NONE.
 */
void cmdWrite(
        Uint16 cmd,
        Uint16 cs_flag)
{
    CSL_lcdcLiddWriteCsAddr (hLcdc, (CSL_LcdcChipSelect)cs_flag, cmd);
}

/**
 *  \brief  writing data of LIDD controller.
 *
 *  \param  data      [IN]  data value .
 *  \param  cs_flag   [IN]  chip select 0 or 1.
 *  \return NONE.
 */
void dataWrite(
         Uint16 data,
         Uint16 cs_flag)
{
    if (!cs_flag){
		LCD_LCDLIDDCS0DATA = data;
	}
	else {
		LCD_LCDLIDDCS1DATA = data;
	}
}


/**
 *  \brief function is use to clears whole LCD.
 *
 *  \param  cs_flag     chipselect 0 or 1.
 *  \return NONE.
 */
void lcdClearPanel(Uint16 cs_flag)
{

    int i, j;
       	// white
    cmdWrite(COLUMN_RAM_ADDRESS,cs_flag);	// Set Column Address
   	dataWrite(0x00, cs_flag);		     	//   Default => 0x00 (Start Address)
    dataWrite(0x7F,cs_flag);					//   Default => 0x7F (End Address)			
	//wait(10);

    cmdWrite(ROW_RAM_ADDRESS,cs_flag); 		// Set Row Address
	dataWrite(0x00, cs_flag);				//   Default => 0x00 (Start Address)
    dataWrite(0x7F,cs_flag); 				//   Default => 0x7F (End Address)	
    //wait(10);  
     
    cmdWrite(WRITE_TO_GRAM,cs_flag);		// Enable MCU to Write into RAM	 
		for(i=0;i<128;i++)
		{
			for(j=0;j<128;j++)
			{
				dataWrite(0x00, cs_flag);
				dataWrite(0x00, cs_flag);
#if defined(LCD_262K_COLOR_MODE)
				dataWrite(0x00, cs_flag);
#endif
			}
		}	
}

/**
 *  \brief This is to setup the LCD panel.
 *   Note: This must be called just after lcdcSetup API and before all others.
 *
 *  \param  cs_flag  [IN]   chipselect 0 or 1.
 *  \return NONE
 */
void panelSetup(
          Uint16 cs_flag)
{
		cmdWrite(0xAE, cs_flag);    // sleep mode on
	  
		cmdWrite(0xfd, cs_flag);    // Command Lock
		dataWrite(0x12, cs_flag);   //	
		cmdWrite(0xfd, cs_flag);    // Command Lock
		dataWrite(0xB1, cs_flag);   //	
		cmdWrite(0xAE, cs_flag);    // Sleep mode on
		cmdWrite(0xB3, cs_flag);    // Set Display freq/div
		dataWrite(0xF1, cs_flag);   //		
		cmdWrite(0xCA, cs_flag);    // Set Multiplex ratio
		dataWrite(0x7F, cs_flag);   //
		cmdWrite(0xA2, cs_flag);    // Set Display offset
		dataWrite(0x00, cs_flag);   //
		cmdWrite(0xA1, cs_flag);    // Set Display start line
		dataWrite(0x00, cs_flag);   //		
		cmdWrite(0xA0, cs_flag);    // Set Remap and color depth
#if defined(LCD_262K_COLOR_MODE)
		dataWrite(0xB0, cs_flag);   // 0xb1: 262K color, vertical 0x71: 65K color, vertical
#else
		dataWrite(0x71, cs_flag);   // 0xb1: 262K color, vertical 0x71: 65K color, vertical
#endif
		cmdWrite(0xB5, cs_flag);    // Set GPIO
		dataWrite(0x00, cs_flag);   //		
		cmdWrite(0xAB, cs_flag);    // Function slelction
		dataWrite(0x01, cs_flag);   //			
		cmdWrite(0xB4, cs_flag);    // Set segment low voltage
		dataWrite(0xA0, cs_flag);   //				
		dataWrite(0xB5, cs_flag);   // 
		dataWrite(0x55, cs_flag);   //			
		cmdWrite(0xC1, cs_flag);    // Set contrast current
		dataWrite(0xC8, cs_flag);   //				
		dataWrite(0x80, cs_flag);    // 
		dataWrite(0xC8, cs_flag);   //		
		cmdWrite(0xC7, cs_flag);    // Set Master current control
		dataWrite(0x0F, cs_flag);   //			
		cmdWrite(0xB8, cs_flag);    // Gamma lookup table	
		    dataWrite(0x2, cs_flag);   //34
		    dataWrite(0x3, cs_flag);   //34
		    dataWrite(0x4, cs_flag);   //34
		    dataWrite(0x5, cs_flag);   //34
		    dataWrite(0x6, cs_flag);   //34
		    dataWrite(0x7, cs_flag);   //34
		    dataWrite(0x8, cs_flag);   //34
		    dataWrite(0x9, cs_flag);   //34
		    dataWrite(0xa, cs_flag);   //34
		    dataWrite(0xb, cs_flag);   //34
		    dataWrite(0xc, cs_flag);   //34
		    dataWrite(0xd, cs_flag);   //34
		    dataWrite(0xe, cs_flag);   //34
		    dataWrite(0xf, cs_flag);   //34
		    dataWrite(0x10, cs_flag);   //34
		    dataWrite(0x11, cs_flag);   //34
		    dataWrite(0x12, cs_flag);   //34
		    dataWrite(0x13, cs_flag);   //34
		    dataWrite(0x15, cs_flag);   //34
		    dataWrite(0x17, cs_flag);   //34
		    dataWrite(0x19, cs_flag);   //34
		    dataWrite(0x1B, cs_flag);   //34
		    dataWrite(0x1D, cs_flag);   //34
		    dataWrite(0x1F, cs_flag);   //34
		    dataWrite(0x21, cs_flag);   //34
		    dataWrite(0x23, cs_flag);   //34
		    dataWrite(0x25, cs_flag);   //34
		    dataWrite(0x27, cs_flag);   //34
		    dataWrite(0x2A, cs_flag);   //34
		    dataWrite(0x2D, cs_flag);   //34
		    dataWrite(0x30, cs_flag);   //34
		    dataWrite(0x33, cs_flag);   //34
		    dataWrite(0x36, cs_flag);   //34
		    dataWrite(0x39, cs_flag);   //34
		    dataWrite(0x3C, cs_flag);   //34
		    dataWrite(0x3F, cs_flag);   //34
		    dataWrite(0x42, cs_flag);   //34
		    dataWrite(0x45, cs_flag);   //34
		    dataWrite(0x48, cs_flag);   //34
		    dataWrite(0x4C, cs_flag);   //34
		    dataWrite(0x50, cs_flag);   //34
		    dataWrite(0x54, cs_flag);   //34
		    dataWrite(0x58, cs_flag);   //34
		    dataWrite(0x5C, cs_flag);   //34
		    dataWrite(0x60, cs_flag);   //34
		    dataWrite(0x64, cs_flag);   //34
		    dataWrite(0x68, cs_flag);   //34
		    dataWrite(0x6C, cs_flag);   //34
		    dataWrite(0x70, cs_flag);   //34
		    dataWrite(0x74, cs_flag);   //34
		    dataWrite(0x78, cs_flag);   //34
		    dataWrite(0x7D, cs_flag);   //34
		    dataWrite(0x82, cs_flag);   //34
		    dataWrite(0x87, cs_flag);   //34
		    dataWrite(0x8C, cs_flag);   //34
		    dataWrite(0x91, cs_flag);   //34
		    dataWrite(0x96, cs_flag);   //34
		    dataWrite(0x9B, cs_flag);   //34
		    dataWrite(0xA0, cs_flag);   //34
		    dataWrite(0xA5, cs_flag);   //34
		    dataWrite(0xAA, cs_flag);   //34
		    dataWrite(0xAF, cs_flag);   //34
		    dataWrite(0xB4, cs_flag);   //34

		cmdWrite(0xB1, cs_flag);    // Set Phase lenth
		dataWrite(0x32, cs_flag);   //		
		cmdWrite(0xB2, cs_flag);    // Enhance driving scheme capability
		dataWrite(0xA4, cs_flag);   //				
		dataWrite(0x00, cs_flag);    // 
		dataWrite(0x00, cs_flag);   //				
		cmdWrite(0xBB, cs_flag);    // Set precharge voltage
		dataWrite(0x17, cs_flag);   // 
		cmdWrite(0xB6, cs_flag);    // Set second precharge period	
		dataWrite(0x01, cs_flag);   //			
		cmdWrite(0xBE, cs_flag);    // Set VCOMH voltage
		dataWrite(0x05, cs_flag);   //
		cmdWrite(0xA6, cs_flag);    // Set Display Mode	
	

		cmdWrite(0xAF, cs_flag);    // Set Display Mode	 

		lcdClearPanel(cs_flag);		// clear LCD screen

}

/*-------------------------------------------------------------------------------**
** 	FunctionName: draw_string                                                    **
** 	Description : 	-   The function draws the string specified in the           **
** 						pData at the specified location, with the color          **
** 						specified and with the font set in font table.           **
** 	                                                                             **
** 	Parameters	:	- cs_flag - In - 0                                           **
** 					  startc - In                                                **
** 					  startl - In                                                **
** 					  pData  - In -  The string to be displayed                  **
** 					  Color - In - The color in which the display has to be done **
**                                                                               **
**-------------------------------------------------------------------------------*/
void draw_string (Uint16 startc, Uint16 startl, char *pData,Uint32 Color, Uint16 cs_flag)
{
    Uint16 font, i=0;
    
    
	i = strlen(pData);
    if(i > 16)
        return;
        
	i =0;
    while(1)
    {
        font = *(pData+i);
        if(font != 0)
        {
            draw_font(startc+i*8,startl,font,Color, cs_flag);
            i++;
        }
        else
        {
            break;
        }
    }
}

/*----------------------------------------------------------------------------------**
** 	FunctionName : draw_font                                                        **
** 	Description : 	- The function draws a character in the LCD as in the fonttable **
** 	Parameters	:	- cs_flag - In - 0                                              **
** 					  startc - In                                                   **
** 					  startl - In                                                   **
** 					  pData  - In -  The character to be displayed                  **
** 					  Color - In - The color in which the display has to be done    **
**                                                                                  **
**----------------------------------------------------------------------------------*/
void draw_font(Uint16 col_address, Uint16 row_address, Uint16 font,Uint32 color, Uint16 cs_flag)
{
    unsigned char *pFontTable, *pFont, Data;
    Uint16 i,j,bit;    
    Uint16 Red, Green, Blue;
	Uint16 color16M, color16L;
    
    pFontTable = lcdFontTable;
    pFont = pFontTable + font*16; 

#ifdef LCD_262K_COLOR_MODE
	Blue = (color&0x003F0000)>>16; 
#else
	Blue = (color&0x003F0000)>>17; // taking MBS 5bits
#endif

    Green = (color&0x00003F00)>>8;
    Red = color&0x0000003F;
    color16M = (Blue << 3) + (Green >>3);
	color16L = (Green <<5) + (Red >> 1); // RED takes MSB 5bits

    cmdWrite(COLUMN_RAM_ADDRESS, cs_flag);
	dataWrite(col_address, cs_flag);
	dataWrite(col_address+8-1, cs_flag);        
	//wait(10);     

	cmdWrite(ROW_RAM_ADDRESS, cs_flag); 
	dataWrite(row_address, cs_flag);
	dataWrite(row_address+FONT_BITMAP_SIZE-1, cs_flag);
	//wait(10);

	cmdWrite(WRITE_TO_GRAM, cs_flag);            // Enable MCU to Write into RAM	 

    
    for(i=0; i<FONT_BITMAP_SIZE; i++)
    {
        Data = *(pFont +i);
        for(j=0; j<8; j++)
        {
            bit = Data&(0x80>>j);    
            if(bit == 0)
            {
#ifdef LCD_262K_COLOR_MODE
				dataWrite(0, cs_flag);
#endif 
                dataWrite(0, cs_flag);       //b4 b3 b2 b1 b0 g5 g4 g3
                dataWrite(0, cs_flag);       //g2 g1 g0 r4 r3 r2 r1 r0
                     
            }
            else
            {
#ifdef 	LCD_262K_COLOR_MODE
				dataWrite(Blue, cs_flag);
				dataWrite(Green, cs_flag);
				dataWrite(Red, cs_flag);
#else
                dataWrite(color16M, cs_flag);   //b4 b3 b2 b1 b0 g5 g4 g3    
                dataWrite(color16L, cs_flag);  //g2 g1 g0 r4 r3 r2 r1 r0    
#endif                       
            }
        }
    }
}

/*----------------------------------------------------------------------------------**
** 	FunctionName : draw_ROM_font (6x8 fonts)                                        **
** 	Description : 	- The function draws a character in the LCD as in the fonttable **
** 	Parameters	:	- cs_flag - In - 0                                              **
** 					  startc - In                                                   **
** 					  startl - In                                                   **
** 					  cdata  - In -  The character to be displayed                  **
** 					  Color - In - The color in which the display has to be done    **
**                                                                                  **
**----------------------------------------------------------------------------------*/
void draw_ROM_font (Uint16 col_address, Uint16 row_address, Uint16 font, Uint32 color, Uint16 cs_flag)
{
    Uint16 *pFontTable, *pFont, Data;
    Uint16 i,j,bit;    
    Uint16 Red, Green, Blue;
	Uint16 color16M, color16L;
    
    pFontTable = CharGen_6x8;
    pFont = pFontTable + (font * 3); 

#ifdef LCD_262K_COLOR_MODE
	Blue = (color&0x003F0000)>>16; 
#else
	Blue = (color&0x003F0000)>>17; // taking MBS 5bits
#endif

    Green = (color&0x00003F00)>>8;
    Red = color&0x0000003F;
    color16M = (Blue << 3) + (Green >>3);
	color16L = (Green <<5) + (Red >> 1); // RED takes MSB 5bits

    cmdWrite(COLUMN_RAM_ADDRESS, cs_flag);
	dataWrite(col_address, cs_flag);
	dataWrite(col_address+6-1, cs_flag);        
	//wait(10);     

	cmdWrite(ROW_RAM_ADDRESS, cs_flag); 
	dataWrite(row_address, cs_flag);
	dataWrite(row_address+8-1, cs_flag);
	//wait(10);

	cmdWrite(WRITE_TO_GRAM, cs_flag);            // Enable MCU to Write into RAM	 

    for(i=0; i < 3; i++)  // FONT_BITMAP_SIZE
    {
        Data = *(pFont +i);
        for(j=0; j< 16; j++) // Font Height
        {
            bit = Data&(0x8000>>j);    
            if(bit == 0)
            {
#ifdef LCD_262K_COLOR_MODE
				dataWrite(0, cs_flag);
#endif 
                dataWrite(0, cs_flag);       //b4 b3 b2 b1 b0 g5 g4 g3
                dataWrite(0, cs_flag);       //g2 g1 g0 r4 r3 r2 r1 r0
                     
            }
            else
            {
#ifdef 	LCD_262K_COLOR_MODE
				dataWrite(Blue, cs_flag);
				dataWrite(Green, cs_flag);
				dataWrite(Red, cs_flag);
#else
                dataWrite(color16M, cs_flag);   //b4 b3 b2 b1 b0 g5 g4 g3    
                dataWrite(color16L, cs_flag);  //g2 g1 g0 r4 r3 r2 r1 r0    
#endif                       
            }
        }
    }
}

/*-------------------------------------------------------------------------------**
** 	FunctionName: draw_ROM_string                                                    **
** 	Description : 	-   The function draws the string specified in the           **
** 						pData at the specified location, with the color          **
** 						specified and with the font set in font table.           **
** 	                                                                             **
** 	Parameters	:	- cs_flag - In - 0                                           **
** 					  startc - In                                                **
** 					  startl - In                                                **
** 					  pData  - In -  The string to be displayed                  **
** 					  Color - In - The color in which the display has to be done **
**                                                                               **
**-------------------------------------------------------------------------------*/
void draw_ROM_string (Uint16 startc, Uint16 startl, unsigned char *pData,Uint32 Color, Uint16 cs_flag)
{
    Uint16 font;
    Uint16 i=0, len;
       
    len = 16;

    for (i=0; i < len; i++)
    {
        font = *(pData+i);
        draw_ROM_font(startc+i*6, startl, font, Color, cs_flag);

    }
}

/*-------------------------------------------------------------------------------**
** 	FunctionName: draw_ROM_table                                                 **
** 	Description : 	-   The function draws the string specified in the           **
** 						pData at the specified location, with the color          **
** 						specified and with the font set in font table.           **
** 	                                                                             **
** 	Parameters	:	- cs_flag - In - 0                                           **
** 					  startc - In                                                **
** 					  startl - In                                                **
** 					  Color - In - The color in which the display has to be done **
**                                                                               **
**-------------------------------------------------------------------------------*/
void draw_ROM_table (Uint16 startc, Uint16 startl, Uint32 Color, Uint16 cs_flag)
{
	Uint16 i,j;
	unsigned char line[16];

	cmdWrite(0xA0, cs_flag);    // Set Remap and color depth
#if defined(LCD_262K_COLOR_MODE)
	dataWrite(0xB0, cs_flag);   // 0xb1: 262K color, vertical 0x71: 65K color, vertical
#else
	dataWrite(0x71, cs_flag);   // 0xb1: 262K color, vertical 0x71: 65K color, vertical
#endif
	
	for (i=0; i < 16; i++) {		
		for (j=0; j < 16; j++) {
			line[j] = j + i*16;
		}
		draw_ROM_string ( startc,  startl, line, Color,  cs_flag);
		startl += 8; 
	}

	cmdWrite(0xA0, cs_flag);    // Set Remap and color depth
#if defined(LCD_262K_COLOR_MODE)
	dataWrite(0xB0, cs_flag);   // 0xb1: 262K color, vertical 0x71: 65K color, vertical
#else
	dataWrite(0x70, cs_flag);   // 0xb1: 262K color, vertical 0x71: 65K color, vertical
#endif	
}

extern Bool ti_logo32[];

/**
 *  \brief to Draw TI LOGO on LCD 
 *
 *  \param  cs_flag  [IN] chip select 0 or 1.
 *  \return Int16  status of call, whether a success(0) or not(other than 0)
 */
Int16 draw_ti_logo(Uint16 cs_flag)
{
	Uint16  i, j;
		
   	cmdWrite(COLUMN_RAM_ADDRESS, cs_flag);		    
    dataWrite(0x04, cs_flag);		     
    dataWrite(0x23, cs_flag);					
	
    cmdWrite(ROW_RAM_ADDRESS, cs_flag);		
	dataWrite(10, cs_flag);				
    dataWrite(0x7f, cs_flag);			  	

    cmdWrite(WRITE_TO_GRAM, cs_flag);			 

	for(i=0;i<32;i++)
	{
		for(j=0;j<32;j++)
		{
			if (ti_logo32[j+i*32] == 1) {
				dataWrite(0x00, cs_flag);   //b4 b3 b2 b1 b0 g5 g4 g3

#ifdef LCD_262K_COLOR_MODE
				dataWrite(0x00, cs_flag);	// Green
				dataWrite(0x3F, cs_flag);	// Red
#endif
#ifdef LCD_65K_COLOR_MODE
				dataWrite(0x1F, cs_flag);	//g2 g1 g0 r4 r3 r2 r1 r0
#endif
			}
			else {
				dataWrite(0x00, cs_flag);   //b4 b3 b2 b1 b0 g5 g4 g3
				dataWrite(0x00, cs_flag);	//g2 g1 g0 r4 r3 r2 r1 r0
#ifdef LCD_262K_COLOR_MODE
				dataWrite(0x00, cs_flag);
#endif
			}
		}
	}

	return LCDC_SOK;
}

/**
 *  \brief to Draw a rectangle on LCD.
 *
 *  \param  colStart  [IN] start address of column.
 *  \param  rowStart  [IN] start address of row.
 *  \param  colEnd    [IN] End address of column.
 *  \param  rowEnd    [IN] End address of row.
 *  \param  outColor  [IN] color of barder.
 *  \param  fillColor [IN] color of inside rectangle.
 *  \param  cs_flag   [IN] chip select 0 or 1.
 *  \return Int16  status of call, whether a success(0) or not(other than 0)
 */
Int16 drawRectangle(
               Uint16     colStart,
               Uint16     rowStart,
               Uint16     colEnd,
               Uint16     rowEnd,
               Uint32     color,
               Uint16     cs_flag )
{
    int i, j;
    Uint16 Red, Green, Blue;
	Uint16 color16M, color16L;

#ifdef LCD_262K_COLOR_MODE
	Blue = (color&0x003F0000)>>16; 
#else
	Blue = (color&0x003F0000)>>17; // taking MBS 5bits
#endif

    Green = (color&0x00003F00)>>8;
    Red = color&0x0000003F;
    color16M = (Blue << 3) + (Green >>3);
	color16L = (Green <<5) + (Red >> 1); // RED takes MSB 5bits
       	// white
    cmdWrite(COLUMN_RAM_ADDRESS,cs_flag);	// Set Column Address
   	dataWrite(colStart, cs_flag);		     	//   Default => 0x00 (Start Address)
    dataWrite(colEnd-1,cs_flag);					//   Default => 0x7F (End Address)			
	//wait(10);

    cmdWrite(ROW_RAM_ADDRESS,cs_flag); 		// Set Row Address
	dataWrite(rowStart, cs_flag);				//   Default => 0x00 (Start Address)
    dataWrite(rowEnd-1,cs_flag); 				//   Default => 0x7F (End Address)	
    //wait(10);  
     
    cmdWrite(WRITE_TO_GRAM,cs_flag);		// Enable MCU to Write into RAM	 
		for(i=0;i<(rowEnd-rowStart);i++)
		{
			for(j=0;j<(colEnd-colStart);j++) //rowEnd-rowStart
			{
#ifdef 	LCD_262K_COLOR_MODE
				dataWrite(Blue, cs_flag);
				dataWrite(Green, cs_flag);
				dataWrite(Red, cs_flag);
#else
                dataWrite(color16M, cs_flag);   //b4 b3 b2 b1 b0 g5 g4 g3    
                dataWrite(color16L, cs_flag);  //g2 g1 g0 r4 r3 r2 r1 r0    
#endif                       
			}
		}	
	return 0;
}

